@@ -3,19 +3,18 @@
 .. _multi-taper-coh:
 
 
-================================
-Multi-taper coherence estimation
-================================
+===============================
+Multitaper coherence estimation
+===============================
 
 
 Coherence estimation can be done using windowed-spectra. This is the method
-used in the example :ref:`resting-state`. In addition, multi-taper spectral
+used in the example :ref:`resting-state`. In addition, multitaper spectral
 estimation can be used in order to calculate coherence and also confidence
 intervals for the coherence values that result (see :ref:`multi-taper-psd`)
 
-
 The data analyzed here is an fMRI data-set contributed by Beth Mormino. The
-data is taken from a single subject in a"resting-state" scan, in which subjects
+data is taken from a single subject in a "resting-state" scan, in which subjects
 are fixating on a cross and maintaining alert wakefulness, but not performing
 any other behavioral task.
 
@@ -25,11 +24,14 @@ objects and as upper and lower bounds on the frequency range analyzed:
 
 """
 
+import os
+
 import numpy as np
 import matplotlib.pyplot as plt
-from matplotlib.mlab import csv2rec
 import scipy.stats.distributions as dist
+from scipy import fftpack
 
+import nitime
 from nitime.timeseries import TimeSeries
 from nitime import utils
 import nitime.algorithms as alg
@@ -47,7 +49,11 @@ We read in the data into a recarray from a csv file:
 
 """
 
-data_rec = csv2rec('data/fmri_timeseries.csv')
+data_path = os.path.join(nitime.__path__[0], 'data')
+
+fname = os.path.join(data_path, 'fmri_timeseries.csv')
+
+data_rec = np.genfromtxt(fname, dtype=float, delimiter=',', names=True)
 
 
 """
@@ -93,14 +99,14 @@ tapers, eigs = alg.dpss_windows(n_samples, NW, K)
 
 """
 
-We multiply the data by the tapers and derive the fourier transform and the
+We multiply the data by the tapers and derive the Fourier transform and the
 magnitude of the squared spectra (the power) for each tapered time-series:
 
 """
 
 
 tdata = tapers[None, :, :] * pdata[:, None, :]
-tspectra = np.fft.fft(tdata)
+tspectra = fftpack.fft(tdata)
 ## mag_sqr_spectra = np.abs(tspectra)
 ## np.power(mag_sqr_spectra, 2, mag_sqr_spectra)
 
@@ -112,7 +118,7 @@ the spectrum (the other half is equal):
 
 """
 
-L = n_samples / 2 + 1
+L = n_samples // 2 + 1
 sides = 'onesided'
 
 """
@@ -123,7 +129,7 @@ We estimate adaptive weighting of the tapers, based on the data (see
 """
 
 w = np.empty((nseq, K, L))
-for i in xrange(nseq):
+for i in range(nseq):
     w[i], _ = utils.adaptive_weights(tspectra[i], eigs, sides=sides)
 
 
@@ -145,8 +151,8 @@ Looping over the ROIs:
 
 """
 
-for i in xrange(nseq):
-    for j in xrange(i):
+for i in range(nseq):
+    for j in range(i, nseq):
 
         """
 
@@ -247,18 +253,16 @@ coh = np.mean(coh_mat[:, :, freq_idx], -1)  # Averaging on the last dimension
 
 """
 
-The next line calls the visualization routine which displays the data
+The next line calls the visualization routine which displays the data:
 
 """
 
-
 fig01 = drawmatrix_channels(coh,
                             roi_names,
                             size=[10., 10.],
                             color_anchor=0,
                             title='MTM Coherence')
 
-
 """
 
 .. image:: fig/multi_taper_coh_01.png
@@ -269,16 +273,14 @@ We start by initializing a TimeSeries object with this data and with the
 sampling_interval provided above. We set the metadata 'roi' field with the ROI
 names.
 
-
 """
 
 T = TimeSeries(pdata, sampling_interval=TR)
 T.metadata['roi'] = roi_names
 
-
 """
 
-We initialize an MTCoherenceAnalyzer object with the TimeSeries object
+We initialize an MTCoherenceAnalyzer object with the TimeSeries object:
 
 """
 
@@ -292,8 +294,8 @@ The relevant indices in the Analyzer object are derived:
 
 freq_idx = np.where((C2.frequencies > 0.02) * (C2.frequencies < 0.15))[0]
 
-
 """
+
 The call to C2.coherence triggers the computation and this is averaged over the
 frequency range of interest in the same line and then displayed:
 
@@ -306,15 +308,13 @@ fig02 = drawmatrix_channels(coh,
                             color_anchor=0,
                             title='MTCoherenceAnalyzer')
 
-
 """
 
 .. image:: fig/multi_taper_coh_02.png
 
-
 For comparison, we also perform the analysis using the standard
 CoherenceAnalyzer object, which does the analysis using Welch's windowed
-periodogram, instead of the multi-taper spectral estimation method (see
+periodogram, instead of the multitaper spectral estimation method (see
 :ref:`resting_state` for a more thorough analysis of this data using this
 method):
 
@@ -332,15 +332,12 @@ fig03 = drawmatrix_channels(coh,
                             color_anchor=0,
                             title='CoherenceAnalyzer')
 
-
 """
 
 .. image:: fig/multi_taper_coh_03.png
 
-
 plt.show() is called in order to display the figures:
 
-
 """
 
 plt.show()
