@@ -94,7 +94,7 @@ def test_get_spectra_complex():
 
 def test_get_spectra_unknown_method():
     """
-    Test that providing an unknown method to get_spectra rasies a ValueError
+    Test that providing an unknown method to get_spectra raises a ValueError
 
     """
     tseries = np.array([[1, 2, 3], [4, 5, 6]])
@@ -179,7 +179,7 @@ def test_dpss_properties():
     N = 2000
     NW = 200
     d, lam = tsa.dpss_windows(N, NW, 2*NW-2)
-    # 2NW-2 lamdas should be all > 0.9
+    # 2NW-2 lambdas should be all > 0.9
     npt.assert_(
         (lam > 0.9).all(), 'Eigenvectors show poor spectral concentration'
         )
@@ -246,8 +246,7 @@ def test_mtm_lin_combo():
         mtm_cross = tsa.mtm_cross_spectrum(
             spec1, spec2, (weights[0], weights[1]), sides=sides
             )
-        npt.assert_(mtm_cross.dtype in np.sctypes['complex'],
-               'Wrong dtype for crossspectrum')
+        assert mtm_cross.dtype == np.complex128, 'Wrong dtype for crossspectrum'
         npt.assert_(len(mtm_cross) == 51,
                'Wrong length for halfband spectrum')
         sides = 'twosided'
@@ -260,8 +259,7 @@ def test_mtm_lin_combo():
         mtm_auto = tsa.mtm_cross_spectrum(
             spec1, spec1, weights[0], sides=sides
             )
-        npt.assert_(mtm_auto.dtype in np.sctypes['float'],
-               'Wrong dtype for autospectrum')
+        assert mtm_auto.dtype == np.float64, 'Wrong dtype for autospectrum'
         npt.assert_(len(mtm_auto) == 51,
                'Wrong length for halfband spectrum')
         sides = 'twosided'
