@@ -4,7 +4,7 @@ from nitime import descriptors as desc
 from nitime import timeseries as ts
 from nitime import algorithms as tsa
 
-# To suppport older versions of numpy that don't have tril_indices:
+# To support older versions of numpy that don't have tril_indices:
 from nitime.index_utils import tril_indices
 
 from .base import BaseAnalyzer
@@ -19,11 +19,12 @@ class CorrelationAnalyzer(BaseAnalyzer):
         Parameters
         ----------
 
-        input: TimeSeries object
+        input : TimeSeries object
            Containing the data to analyze.
 
         Examples
         --------
+        >>> np.set_printoptions(precision=4)  # for doctesting
         >>> t1 = ts.TimeSeries(data = np.sin(np.arange(0,
         ...                    10*np.pi,10*np.pi/100)).reshape(2,50),
         ...                                      sampling_rate=np.pi)
@@ -32,10 +33,10 @@ class CorrelationAnalyzer(BaseAnalyzer):
         >>> c1.corrcoef
         array([[ 1., -1.],
                [-1.,  1.]])
-        >>> c1.xcorr.sampling_rate
-        3.1415926536 Hz
-        >>> c1.xcorr.t0
-        -15.91549430915 s
+        >>> c1.xcorr.sampling_rate  # doctest: +ELLIPSIS
+        3.141592653... Hz
+        >>> c1.xcorr.t0  # doctest: +ELLIPSIS
+        -15.91549430915... s
 
         """
 
@@ -55,7 +56,7 @@ class CorrelationAnalyzer(BaseAnalyzer):
         Returns
         -------
 
-        TimeSeries: the time-dependent cross-correlation, with zero-lag
+        TimeSeries : the time-dependent cross-correlation, with zero-lag
         at time=0
 
         """
@@ -65,9 +66,9 @@ class CorrelationAnalyzer(BaseAnalyzer):
                           tseries_length,
                           t_points * 2 - 1))
         data = self.input.data
-        for i in xrange(tseries_length):
+        for i in range(tseries_length):
             data_i = data[i]
-            for j in xrange(i, tseries_length):
+            for j in range(i, tseries_length):
                 xcorr[i, j] = np.correlate(data_i,
                                           data[j],
                                           mode='full')
@@ -88,7 +89,7 @@ class CorrelationAnalyzer(BaseAnalyzer):
         Returns
         -------
 
-        TimeSeries: A TimeSeries object
+        TimeSeries : A TimeSeries object
             the time-dependent cross-correlation, with zero-lag at time=0
 
         """
@@ -99,9 +100,9 @@ class CorrelationAnalyzer(BaseAnalyzer):
                           tseries_length,
                           t_points * 2 - 1))
         data = self.input.data
-        for i in xrange(tseries_length):
+        for i in range(tseries_length):
             data_i = data[i]
-            for j in xrange(i, tseries_length):
+            for j in range(i, tseries_length):
                 xcorr[i, j] = np.correlate(data_i,
                                           data[j],
                                           mode='full')
@@ -130,9 +131,9 @@ class SeedCorrelationAnalyzer(object):
         Parameters
         ----------
 
-        seed_time_series: a time-series object
+        seed_time_series : a TimeSeries object
 
-        target_time_series: a time-series object
+        target_time_series : a TimeSeries object
 
         """
         self.seed = seed_time_series
@@ -146,7 +147,7 @@ class SeedCorrelationAnalyzer(object):
 
             # Preallocate results
             Cxy = np.empty((self.seed.data.shape[0],
-                            self.target.data.shape[0]), dtype=np.float)
+                            self.target.data.shape[0]), dtype=float)
 
             for seed_idx, this_seed in enumerate(self.seed.data):
 
