@@ -1,7 +1,7 @@
-
 import numpy as np
-import scipy
-import scipy.signal as signal
+from nitime.lazy import scipy
+from nitime.lazy import scipy_signal as signal
+from nitime.lazy import scipy_fftpack as fftpack
 
 from nitime import descriptors as desc
 from nitime import utils as tsu
@@ -13,7 +13,8 @@ from .base import BaseAnalyzer
 
 class SpectralAnalyzer(BaseAnalyzer):
     """ Analyzer object for spectral analysis"""
-    def __init__(self, input=None, method=None, BW=None, adaptive=False, low_bias=False):
+    def __init__(self, input=None, method=None, BW=None, adaptive=False,
+                 low_bias=False):
         """
         The initialization of the
 
@@ -48,8 +49,8 @@ class SpectralAnalyzer(BaseAnalyzer):
         >>> s1 = SpectralAnalyzer(t1)
         >>> s1.method['this_method']
         'welch'
-        >>> s1.method['Fs']
-        3.14159265359 Hz
+        >>> s1.method['Fs'] # doctest: +ELLIPSIS
+        3.1415926535... Hz
         >>> f,s = s1.psd
         >>> f
         array([ 0.    ,  0.0491,  0.0982,  0.1473,  0.1963,  0.2454,  0.2945,
@@ -72,7 +73,6 @@ class SpectralAnalyzer(BaseAnalyzer):
         self.adaptive = adaptive
         self.low_bias = low_bias
 
-
     @desc.setattr_on_read
     def psd(self):
         """
@@ -91,25 +91,28 @@ class SpectralAnalyzer(BaseAnalyzer):
             psd_len = NFFT
             dt = complex
         else:
-            psd_len = NFFT / 2.0 + 1
+            psd_len = NFFT // 2 + 1
             dt = float
-        psd = np.empty((self.input.shape[0],
-                       psd_len), dtype=dt)
 
         #If multi-channel data:
         if len(self.input.data.shape) > 1:
-            for i in xrange(self.input.data.shape[0]):
+            psd_shape = (self.input.shape[:-1] + (psd_len,))
+            flat_data = np.reshape(self.input.data, (-1,
+                                                     self.input.data.shape[-1]))
+            flat_psd = np.empty((flat_data.shape[0], psd_len), dtype=dt)
+            for i in range(flat_data.shape[0]):
                 #'f' are the center frequencies of the frequency bands
                 #represented in the psd. These are identical in each iteration
                 #of the loop, so they get reassigned into the same variable in
                 #each iteration:
-                temp, f = tsa.mlab.psd(self.input.data[i],
+                temp, f = tsa.mlab.psd(flat_data[i],
                             NFFT=NFFT,
                             Fs=Fs,
                             detrend=detrend,
                             window=window,
                             noverlap=n_overlap)
-                psd[i] = temp.squeeze()
+                flat_psd[i] = temp.squeeze()
+            psd = np.reshape(flat_psd, psd_shape).squeeze()
 
         else:
             psd, f = tsa.mlab.psd(self.input.data,
@@ -173,9 +176,15 @@ class SpectralAnalyzer(BaseAnalyzer):
         data = self.input.data
         sampling_rate = self.input.sampling_rate
 
-        fft = np.fft.fft
-        f = tsu.get_freqs(sampling_rate, data.shape[-1])
-        spectrum_fourier = fft(data)[..., :f.shape[0]]
+        fft = fftpack.fft
+        if np.any(np.iscomplex(data)):
+            # Get negative frequencies, as well as positive:
+            f = np.linspace(-sampling_rate/2., sampling_rate/2., data.shape[-1])
+            spectrum_fourier = np.fft.fftshift(fft(data))
+        else:
+            f = tsu.get_freqs(sampling_rate, data.shape[-1])
+            spectrum_fourier = fft(data)[..., :f.shape[0]]
+
         return f, spectrum_fourier
 
     @desc.setattr_on_read
@@ -186,13 +195,20 @@ class SpectralAnalyzer(BaseAnalyzer):
         :func:`multi_taper_csd'
 
         """
+        if np.iscomplexobj(self.input.data):
+            psd_len = self.input.shape[-1]
+            dt = complex
+        else:
+            psd_len = self.input.shape[-1] // 2 + 1
+            dt = float
+
         #Initialize the output
-        spectrum_multi_taper = np.empty((self.input.shape[0],
-                                         self.input.shape[-1] / 2 + 1))
+        spectrum_multi_taper = np.empty((self.input.shape[:-1] + (psd_len,)),
+                                         dtype=dt)
 
         #If multi-channel data:
         if len(self.input.data.shape) > 1:
-            for i in xrange(self.input.data.shape[0]):
+            for i in range(self.input.data.shape[0]):
                 # 'f' are the center frequencies of the frequency bands
                 # represented in the MT psd. These are identical in each
                 # iteration of the loop, so they get reassigned into the same
@@ -205,10 +221,10 @@ class SpectralAnalyzer(BaseAnalyzer):
                     low_bias=self.low_bias)
         else:
             f, spectrum_multi_taper, _ = tsa.multi_taper_psd(self.input.data,
-                                                          Fs=self.input.sampling_rate,
-                                                          BW=self.BW,
-                                                          adaptive=self.adaptive,
-                                                          low_bias=self.low_bias)
+                                                  Fs=self.input.sampling_rate,
+                                                  BW=self.BW,
+                                                  adaptive=self.adaptive,
+                                                  low_bias=self.low_bias)
 
         return f, spectrum_multi_taper
 
@@ -260,11 +276,12 @@ class FilterAnalyzer(desc.ResetMixin):
 
         #Initialize all the local variables you will need for all the different
         #filtering methods:
-        self.data = time_series.data
-        self.sampling_rate = time_series.sampling_rate
+        self._ts = time_series
+        self.data = self._ts.data
+        self.sampling_rate = self._ts.sampling_rate
         self.ub = ub
         self.lb = lb
-        self.time_unit = time_series.time_unit
+        self.time_unit = self._ts.time_unit
         self._boxcar_iterations = boxcar_iterations
         self._gstop = gstop
         self._gpass = gpass
@@ -296,32 +313,35 @@ class FilterAnalyzer(desc.ResetMixin):
         if in_ts is not None:
             data = in_ts.data
             Fs = in_ts.sampling_rate
-            tu = in_ts.time_unit
+            t0 = in_ts.t0
+            time_unit = in_ts.time_unit
         else:
-            data = self.data
-            Fs = self.sampling_rate
-            tu = self.time_unit
+            data = self._ts.data
+            Fs = self._ts.sampling_rate
+            t0 = self._ts.t0
+            time_unit = self._ts.time_unit
 
-        #filtfilt only operates channel-by-channel, so we need to loop over the
-        #channels, if the data is multi-channel data:
+        # filtfilt only operates channel-by-channel, so we need to loop over
+        # the channels, if the data is multi-channel data:
         if len(data.shape) > 1:
-            out_data = np.empty(data.shape)
-            for i in xrange(data.shape[0]):
+            out_data = np.empty(data.shape, dtype=data.dtype)
+            for i in range(data.shape[0]):
                 out_data[i] = signal.filtfilt(b, a, data[i])
-                #Make sure to preserve the DC:
+                # Make sure to preserve the DC:
                 dc = np.mean(data[i])
-                out_data[i] -= np.mean(out_data[i])
-                out_data[i] += dc
+                out_data[i] = out_data[i] - np.mean(out_data[i])
+                out_data[i] = out_data[i] + dc
         else:
             out_data = signal.filtfilt(b, a, data)
-            #Make sure to preserve the DC:
+            # Make sure to preserve the DC:
             dc = np.mean(data)
             out_data -= np.mean(out_data)
             out_data += dc
 
         return ts.TimeSeries(out_data,
                              sampling_rate=Fs,
-                             time_unit=self.time_unit)
+                             time_unit=time_unit,
+                             t0=t0)
 
     @desc.setattr_on_read
     def fir(self):
@@ -349,8 +369,8 @@ class FilterAnalyzer(desc.ResetMixin):
 
         n_taps = self._filt_order + 1
 
-        #This means the filter order you chose was too large (needs to be
-        #shorter than a 1/3 of your time-series )
+        # This means the filter order you chose was too large (needs to be
+        # shorter than a 1/3 of your time-series )
         if n_taps > self.data.shape[-1] * 3:
             e_s = "The filter order chosen is too large for this time-series"
             raise ValueError(e_s)
@@ -358,18 +378,20 @@ class FilterAnalyzer(desc.ResetMixin):
         # a is always 1:
         a = [1]
 
-        sig = ts.TimeSeries(data=self.data, sampling_rate=self.sampling_rate)
+        sig = ts.TimeSeries(data=self._ts.data,
+                            sampling_rate=self._ts.sampling_rate,
+                            t0=self._ts.t0)
 
-        #Lowpass:
+        # Lowpass:
         if ub_frac < 1:
             b = signal.firwin(n_taps, ub_frac, window=self._win)
             sig = self.filtfilt(b, a, sig)
 
-        #High-pass
+        # High-pass
         if lb_frac > 0:
             #Includes a spectral inversion:
             b = -1 * signal.firwin(n_taps, lb_frac, window=self._win)
-            b[n_taps / 2] = b[n_taps / 2] + 1
+            b[n_taps // 2] = b[n_taps // 2] + 1
             sig = self.filtfilt(b, a, sig)
 
         return sig
@@ -391,11 +413,23 @@ class FilterAnalyzer(desc.ResetMixin):
 
         lb_frac = self.lb / (self.sampling_rate / 2.)
 
-        wp = [lb_frac, ub_frac]
+        # For the band-pass:
+        if lb_frac > 0 and ub_frac < 1:
 
-        #Make sure to not exceed the interval 0-1:
-        ws = [np.max([lb_frac - 0.1, 0]),
-              np.min([ub_frac + 0.1, 1.0])]
+            wp = [lb_frac, ub_frac]
+
+            ws = [np.max([lb_frac - 0.1, 0.001]),
+                  np.min([ub_frac + 0.1, 0.999])]
+
+        # For the lowpass:
+        elif lb_frac == 0:
+            wp = ub_frac
+            ws = np.min([ub_frac + 0.1, 0.9])
+
+        # For the highpass:
+        elif ub_frac == 1:
+            wp = lb_frac
+            ws = np.max([lb_frac - 0.1, 0.1])
 
         b, a = signal.iirdesign(wp, ws, self._gpass, self._gstop,
                                 ftype=self._ftype)
@@ -416,7 +450,7 @@ class FilterAnalyzer(desc.ResetMixin):
         if self.ub is None:
             self.ub = freqs[-1]
 
-        power = np.fft.fft(self.data)
+        power = fftpack.fft(self.data)
         idx_0 = np.hstack([np.where(freqs < self.lb)[0],
                            np.where(freqs > self.ub)[0]])
 
@@ -426,7 +460,7 @@ class FilterAnalyzer(desc.ResetMixin):
         power[..., -1 * idx_0] = 0  # Take care of the negative frequencies
         power[..., 0] = keep_dc  # And put the DC back in when you're done:
 
-        data_out = np.fft.ifft(power)
+        data_out = fftpack.ifft(power)
 
         data_out = np.real(data_out)  # In order to make sure that you are not
                                       # left with float-precision residual
@@ -434,7 +468,8 @@ class FilterAnalyzer(desc.ResetMixin):
 
         return ts.TimeSeries(data=data_out,
                              sampling_rate=self.sampling_rate,
-                             time_unit=self.time_unit)
+                             time_unit=self.time_unit,
+                             t0=self._ts.t0)
 
     @desc.setattr_on_read
     def filtered_boxcar(self):
@@ -459,8 +494,9 @@ class FilterAnalyzer(desc.ResetMixin):
                                      n_iterations=self._boxcar_iterations)
 
         return ts.TimeSeries(data=data_out,
-                                 sampling_rate=self.sampling_rate,
-                                 time_unit=self.time_unit)
+                             sampling_rate=self.sampling_rate,
+                             time_unit=self.time_unit,
+                             t0=self._ts.t0)
 
 
 class HilbertAnalyzer(BaseAnalyzer):
@@ -483,12 +519,7 @@ class HilbertAnalyzer(BaseAnalyzer):
         """The natural output for this analyzer is the analytic signal """
         data = self.input.data
         sampling_rate = self.input.sampling_rate
-        #If you have scipy with the fixed scipy.signal.hilbert (r6205 and
-        #later)
-        if scipy.__version__ >= '0.9':
-            hilbert = signal.hilbert
-        else:
-            hilbert = tsu.hilbert_from_new_scipy
+        hilbert = signal.hilbert
 
         return ts.TimeSeries(data=hilbert(data),
                              sampling_rate=sampling_rate)
@@ -597,7 +628,7 @@ class MorletWaveletAnalyzer(BaseAnalyzer):
                              sampling_rate=sampling_rate, ns=5,
                              normed='area')
 
-            nd = (w.shape[0] - 1) / 2
+            # nd = (w.shape[0] - 1) / 2
             a_signal.data[...] = (np.convolve(data, np.real(w), mode='same') +
                             1j * np.convolve(data, np.imag(w), mode='same'))
         else:
@@ -605,7 +636,7 @@ class MorletWaveletAnalyzer(BaseAnalyzer):
                 w = self.wavelet(f, sd, sampling_rate=sampling_rate,
                                  ns=5, normed='area')
 
-                nd = (w.shape[0] - 1) / 2
+                # nd = (w.shape[0] - 1) / 2
                 a_signal.data[i, ...] = (
                     np.convolve(data, np.real(w), mode='same') +
                     1j * np.convolve(data, np.imag(w), mode='same'))
